@@ -69,7 +69,7 @@ validateChronBias <- function(object) {
 # Class definition for chronBias
 # --------------------------------------------
 
-# Randomization paramters generic
+# Randomization parameters generic
 setClass("chronBias",
          slots = c("type" = "character", "theta" = "numeric",
                    method = "character", alpha = "numeric"),
@@ -104,39 +104,43 @@ setClass("chronBias",
 #' \code{randSeq}. The type-I-error rate (power) is the proportion of falsely
 #' (correctly) rejected null hypotheses.
 #' 
-#' If \code{method="exact"}, the object represents the exact type-I-error proabability 
+#' If \code{method="exact"}, the object represents the exact type-I-error probability 
 #'  given the level \code{alpha}, the selection effect \code{eta} and the 
 #'  biasing strategy \code{type}. When calling \code{assess} for a \code{chronBias} 
-#'  object with \code{method="exact"}, the exact \emph{p}-value of each 
-#'  randomization sequence is computed. So far, this is only supported for
-#'  normal endpoints. Then the type-I-error probability is
-#'  the sum of the corresponding quantiles of the doubly noncentral t-distribution.
+#'  object with \code{method="exact"}, the \emph{p}-value of each randomization
+#'  sequence is computed. For normal endpoints and two treatment groups these p-values 
+#'  are exact values which can be calculated from the sum of the corresponding quantiles 
+#'  of the doubly noncentral t-distribution. For more than two treatment groups, exact 
+#'  p-values are computed using a doubly noncentral F distribution. For exponential 
+#'  endpoints the p-values are obtained using an approximation formula. 
 #'
 #' \subsection{Types of chronological bias}{
 #' \describe{
 #' 	 \item{\code{type = "linT"}}{
-#'    Represents linear time trend. Linear time trend means that the expected response
-#' 	  of the patients increases evenly by \code{theta} with 
-#'    every patient included in the study, until reaching \code{N theta} after \code{N} patients.
-#'    Linear time trend may occur as a result of gradually relaxing in- or exlusion criteria 
+#'    Represents linear time trend. Linear time trend means that the time trend function of the patients,
+#'    i.e. expected response for normal endpoints, increases evenly by \code{theta/(N-1)} with 
+#'    every patient included in the study, until reaching \code{theta} after \code{N} patients.
+#'    Linear time trend may occur as a result of gradually relaxing in- or exclusion criteria 
 #'    throughout the trial.
-#'    It can be presented by the formula: \deqn{f(i) = i  \theta}{f(i) = i \theta}
+#'    It can be represented by the formula: 
+#'    \deqn{f(i) = (i-1)/(N-1) \theta}{f(i) = (i-1)/(N-1) \theta}
 #'   }
 #' 	 \item{\code{type = "logT"}}{
-#'    Represents logistic time trend. Logistic time trend means that the expected response
-#' 	  of the patients increases logistically in the patient index by \code{theta} with 
-#'    every patient included in the study, until reaching \code{log(N) theta} after \code{N} patients.
-#'    Logistic time trend may occur as a result of a learning curve, i.e. in a surgical trial.
-#'    It can be presented by the formula:
-#'   \deqn{\log(i) \theta}{f(i) = log(i/N) \theta}
+#'    Represents logarithmic time trend. Logarithmic time trend means that the time trend function of 
+#'    the patients, i.e. expected response for normal endpoints, increases logarithmically in the 
+#'    patient index by \code{theta/log(N)} with every patient included in the study, until reaching 
+#'    \code{theta} after \code{N} patients. Logarithmic time trend may occur as a result of a learning 
+#'    curve, i.e. in a surgical trial. 
+#'    It can be represented by the formula: 
+#'    \deqn{\log(i)/\log(N) \theta}{f(i) = log(i)/log(N) \theta}
 #'   }
 #' 	 \item{\code{type = "stepT"}}{
 #'    Represents step trend. Step trend means that the expected response of the patients increases
 #'    by \code{theta} after a given point (\code{"saltus"}) in the allocation process.
 #'    Step trend may occur if a new device is used after the point \eqn{c} = \code{"saltus"}, or if 
-#'    the medical personal changes after after this point.
-#'    Step time trend can be presented by the formula:
-#'   \deqn{f(i) = 1_{c \leq i \leq N} \theta}{f(i) = 1_{c \le i\le N} \theta }
+#'    the medical personal changes after this point.
+#'    Step time trend can be represented by the formula:
+#'   \deqn{f(i) = 1_{c < i \leq N} \theta}{f(i) = 1_{c < i \le N} \theta}
 #'   }
 #' }
 #' }
@@ -155,6 +159,14 @@ setClass("chronBias",
 #' 
 #' @family issues
 #' 
+#' @examples
+#' # create a linear time trend with theta = 0.5 for which the exact rejection probabilities 
+#' # are calculated
+#' cbias <- chronBias("linT", 0.5, "exact")
+#' 
+#' # create a stepwise time trend with theta = 1 after 10 allocations for which the test 
+#' # decision is simulated  
+#' cbias <- chronBias("stepT", 1, "sim", 10)
 #'
 #' @export
 chronBias <- function(type, theta, method, saltus, alpha = 0.05) {
@@ -175,7 +187,7 @@ setMethod("getStat", signature(randSeq = "randSeq", issue = "chronBias", endp =
           function(randSeq, issue, endp) stop("Need an object of endpoint class."))
 
 # @rdname getStat
-setMethod("getStat", signature(randSeq = "randSeq", issue = "chronBias", endp = "normEndp"),
+setMethod("getStat", signature(randSeq = "randSeq", issue = "chronBias", endp = "endpoint"),
           function(randSeq, issue, endp) {
             validObject(randSeq); validObject(issue); validObject(endp)
             if (issue@method == "sim") {
@@ -190,7 +202,6 @@ setMethod("getStat", signature(randSeq = "randSeq", issue = "chronBias", endp =
           }
 )
 
-
 #' @rdname getExpectation
 setMethod("getExpectation", signature(randSeq = "randSeq", issue = "chronBias", endp = "normEndp"),
           function(randSeq, issue, endp) {
@@ -200,20 +211,20 @@ setMethod("getExpectation", signature(randSeq = "randSeq", issue = "chronBias",
             # linear time trend
             if (issue@type == "linT") {
               issue <- t(apply(randSeq@M, 1, function(x) {
-                1:n * issue@theta
+                0:(n-1)/(n-1) * issue@theta
               }))
             }
 			# logarithmic time trend			
 			else if (issue@type == "logT") {
               issue <- t(apply(randSeq@M, 1, function(x) {
-                log((1:n)/n) * issue@theta
+                log(1:n)/log(n) * issue@theta
               }))  
             } 
 			# step time trend
 			else if (issue@type == "stepT") {
               stopifnot(randSeq@N > issue@saltus)
               issue <- t(apply(randSeq@M, 1, function(x) {
-                c(rep(0, issue@saltus - 1), rep(issue@theta, n - issue@saltus + 1))
+                c(rep(0, issue@saltus), rep(issue@theta, n - issue@saltus))
               }))  
             }
 
@@ -223,28 +234,59 @@ setMethod("getExpectation", signature(randSeq = "randSeq", issue = "chronBias",
           }
 )
 
+#' @rdname getExpectation
+setMethod("getExpectation", signature(randSeq = "randSeq", issue = "chronBias", endp = "expEndp"),
+          function(randSeq, issue, endp) {
+            stopifnot(randSeq@K == 2, randSeq@K == length(endp@lambda))
+            validObject(randSeq); validObject(issue); validObject(endp)
+            n <- N(randSeq)
+            # linear time trend
+            if (issue@type == "linT") {
+              issue <- t(apply(randSeq@M, 1, function(x) {
+                0:(n-1)/(n-1) * issue@theta
+              }))
+            }
+            # logarithmic time trend			
+            else if (issue@type == "logT") {
+              issue <- t(apply(randSeq@M, 1, function(x) {
+                log(1:n)/log(n) * issue@theta
+              }))  
+            } 
+            # step time trend
+            else if (issue@type == "stepT") {
+              stopifnot(randSeq@N > issue@saltus)
+              issue <- t(apply(randSeq@M, 1, function(x) {
+                c(rep(0, issue@saltus), rep(issue@theta, n - issue@saltus))
+              }))  
+            }
+            issue[randSeq@M == 0] <- exp(issue[randSeq@M == 0]) * endp@lambda[1]
+            issue[randSeq@M == 1] <- exp(issue[randSeq@M == 1]) * endp@lambda[2]
+            1/issue
+          }
+)
+
 
 #' @rdname getExpectation
 setMethod("getExpectation", signature(randSeq = "randSeq", issue = "chronBias", endp = "missing"),
           function(randSeq, issue) {
-            stopifnot(randSeq@K == 2)
+            #stopifnot(randSeq@K == 2)
             validObject(randSeq); validObject(issue)
             n <- N(randSeq)
             # linear time trend
             if (issue@type == "linT") {
               issue <- t(apply(randSeq@M, 1, function(x) {
-                1:n * issue@theta
+                0:(n-1)/(n-1) * issue@theta
               }))
             # logarithmic time trend			
             } else if (issue@type == "logT") {
               issue <- t(apply(randSeq@M, 1, function(x) {
-                log((1:n)/n) * issue@theta
+                log(1:n)/log(n) * issue@theta
               })) 
             # step time trend
             } else if (issue@type == "stepT") {
               stopifnot(randSeq@N > issue@saltus, is(issue,"chronBiasStepT"))
               issue <- t(apply(randSeq@M, 1, function(x) {
-                c(rep(0, issue@saltus - 1), rep(issue@theta, n - issue@saltus + 1))
+                c(rep(0, issue@saltus), rep(issue@theta, n - issue@saltus))
               })) 
             }
             issue
